@@ -183,9 +183,11 @@ int  main(int argc, char **argv)
   uselessCheckTime=time(NULL);
   DelUselessSessions();
 
+  DelOldMacInfoInWorkDb(); /**********************************/
   /*** enter infinite loop of packet inspection ***/
   while(1){
 
+    
     /* if sig-hup flag is on, reload this program */
     /* sig-hup flag is set in sigHupHandler, when HUP signal arrives */
     if(sigHupArrived)execlp(argv[0], argv[0], NULL);
@@ -210,10 +212,12 @@ int  main(int argc, char **argv)
     /* if no packet */
     if(ret==0){
  
-      /* when long time passed from previous check, check&delete useless sessions */
+      /* when long time passed from previous check, */
+      /* check&delete useless sessions and old macinfo */
       if( time(NULL) - uselessCheckTime > checkInterval ){
 	uselessCheckTime = time(NULL);
 	DelUselessSessions();
+	DelOldMacInfoInWorkDb();
       }
 
       /* and return to loop top */
@@ -304,11 +308,11 @@ int  main(int argc, char **argv)
       SetMacIpPair(macAddress, ipAddress, userId, extraId);
     }
 
-    /*  check useless sessions at some interval */
-    /* (MAC and IP pairs are removed in stop session) */
+    /*  check useless sessions and old macinfo at some interval */
     if( time(NULL) - uselessCheckTime > checkInterval ){
       uselessCheckTime = time(NULL);
       DelUselessSessions();
+      DelOldMacInfoInWorkDb();
     }
   }
   /*** end of infinite loop ***/
