@@ -87,8 +87,6 @@ int addSession(char* macAddress, char* userId, char* extraId){
   /* write open log to syslog */
   WriteOpenToSyslog(userId, extraId, macAddress);
 
-  /* write log to management db */
-  PutOpenToMngDb(macAddress);
   return TRUE;
 }
 
@@ -122,9 +120,6 @@ void delSession(char* macAddress){
   if(debug>0) WriteSessionInfoToSyslog(userId, extraId, 
 				       macAddress, ruleNumber);
 
-  /* write close log to management db */
-  PutCloseToMngDb(macAddress);
-
   /* reset the memory of MAC IP pair */
   ResetMacIpPairs(macAddress);
 }
@@ -180,9 +175,6 @@ int closeSession(void* pParam, int argc, char *argv[], char* colName[]){
   WriteCloseToSyslog(userId, extraId,  macAddress, openTime);
   if(debug>0) WriteSessionInfoToSyslog(userId, extraId, macAddress, ruleNumber);
 
-  /* write close log to management db */
-  PutCloseToMngDb(macAddress);
-
   /* reset the memory of MAC IP pair */
   ResetMacIpPairs(macAddress);
 
@@ -338,7 +330,6 @@ void removeSessionUnmatchedToIpfwRule(DB* ruleTable, DB* sessionTable){
 	err_msg("ERR at %s#%d: fail to get session info",__FILE__,__LINE__);
       }else{
 	WriteCloseToSyslog(userId, extraId, macAddress, openTime);
-	PutCloseToMngDb(macAddress);
 	DelSessionFromWorkDb(macAddress);
       }
 
@@ -396,7 +387,6 @@ void  removeIpfwRuleUnmatchedToSession(DB* ruleTable, DB* sessionTable){
 
       /* write log */
       WriteCloseToSyslog("?", "", macAddress, time(NULL));
-      PutCloseToMngDb(macAddress);
       
       /* write session info to syslog (no user info)*/
       if(debug>0) WriteSessionInfoToSyslog("?","", macAddress, ruleNumber);
@@ -480,10 +470,6 @@ void setMacIpPair(char* macAddress, char* ipAddress, char* userId, char* extraId
   if(!IsFoundMacIpPairInWorkDb(macAddress, ipAddress)){
     PutMacIpPairToWorkDb(macAddress, ipAddress);
 
-    /* record the pair to management db */
-    /* the pair in management db is the sccess log (don't remove at the end of session)*/
-    PutMacIpPairToMngDb(macAddress, ipAddress);
-
     /* write to syslog */
     if(isNull(extraId)){
       err_msg("FIND: user %s from %s at %s", userId, ipAddress, macAddress);
