@@ -553,6 +553,26 @@ int delMacIpPairsInWorkDb(char* macAddress){
 
 }
 
+/********************************************
+Delete old mac info in work db
+ (detected before 1 month)
+********************************************/
+int delOldMacInfoInWorkDb(void){
+  char *pErrMsg=NULL;
+
+  /* SQL DELETE COMMAND */
+  char *deleteCmd="DELETE FROM macinfo WHERE detectTime<strftime('%s','now','-1 month')";
+  int resultFlag=TRUE;
+
+  /* execute delete */
+  if(sqlite3_exec(dbMd, deleteCmd, NULL, NULL, &pErrMsg)!=SQLITE_OK){
+    resultFlag=FALSE;
+    err_msg("ERR at %s#%d: sqlite3_exec: %s",__FILE__,__LINE__,pErrMsg);
+  }
+
+  return resultFlag;
+}
+
 /*********************************************************
  routines for debugging output
 *********************************************************/
@@ -685,3 +705,11 @@ int DelMacIpPairsInWorkDb(char* macAddress){
   if(debug>1) err_msg("DEBUG:(%d)<=delMacIpPairsInWorkDb( )", ret);
   return ret;
 }
+
+int DelOldMacInfoInWorkDb(void){
+  int ret;
+  if(debug>1) err_msg("DEBUG:=>delOldMacInfoInWorkDb()");
+  ret=delOldMacInfoInWorkDb();
+  if(debug>1) err_msg("DEBUG:(%d)<=delOldMacInfoInWorkDb()", ret);
+  return ret;
+}
