@@ -1,7 +1,7 @@
 /**************************************************
 OpengateM - MAC address authentication system 
  module for Authentication by FTPS
-       (Explicit and Implicit modes)
+       (Explicit and Implicit FTP modes)
 
 Copyright (C) 2006 Opengate Project Team
 Written by Yoshiaki Watanabe
