@@ -36,7 +36,7 @@ int authLdap(char *userid, char *passwd)
 {
 
 #ifdef LDAP_NOT_INSTALLED
-  err_msg("ERR at %s#%d: No LDAP. Install openldap-client and rebuild Opengate.",
+  err_msg("ERR at %s#%d: No LDAP. Install openldap-client and rebuild OpengateM.",
 	    __FILE__,__LINE__);
   return DENY;
 #else
@@ -53,11 +53,11 @@ int authLdap(char *userid, char *passwd)
   struct berval cred = { strlen(passwd), passwd };
   struct berval *msgidp=NULL;
 
-  /* get LDAP server URI */
+  /* get LDAP server URI from conf */
   uri=GetConfValue("AuthServer/Uri");
   if(isNull(uri)) uri=NULL; /* means ldap://localhost */
  
-  /* get LDAP search base DN */
+  /* get LDAP search base DN from conf */
   baseDn=GetConfValue("AuthServer/BaseDN");
   if(isNull(baseDn)) baseDn=NULL; /* set in uri */
   
@@ -84,7 +84,7 @@ int authLdap(char *userid, char *passwd)
     return DENY;
   }
   
-  /* set filter */
+  /* set filter '(uid=<userid>)' */
   strlcpy(filter, "(uid=", BUFFMAXLN);
   strlcat(filter, userid, BUFFMAXLN);
   strlcat(filter, ")", BUFFMAXLN);
@@ -126,8 +126,8 @@ int authLdap(char *userid, char *passwd)
 }
 
   
-
-  
+/***********************************
+ **********************************/  
 int AuthLdap(char *userid, char *passwd)
 {
   int ret;
