@@ -9,19 +9,24 @@
 #include	<stdarg.h>		/* ANSI C header file */
 #include	<syslog.h>		/* for syslog() */
 
-int		daemon_proc;
+int		daemon_proc;  /* daemon procedure or not */
 
 static void	err_doit(int, int, const char *, va_list);
 
-/*************************************************/
-/* Nonfatal error related to a system call.
- * Print a message and return. */
-/*************************************************/
+/**********************************************/
+/* set flag of syslog usage                   */
+/* i:(input) TRUE(1)=use syslog (daemon proc) */
+/*           FALSE(0)=use stdout (shell proc) */
+/**********************************************/
 void errToSyslog(int i)
 {
   daemon_proc=i;
 }
 
+/*************************************************/
+/* Non-fatal error related to a system call.     */
+/* Print a message and return.                   */
+/*************************************************/
 void
 err_ret(const char *fmt, ...)
 {
