@@ -317,7 +317,8 @@ int getNextMacAddrFromMngDb(char* userId, char* extraId, char* macAddress, char*
 int putMacModifyLogToMngDb(char* userId, char* extraId, char* macAddr, char modifyType){
 
   char queryStr[BUFFMAXLN];
- 
+
+  /*** insert modify log ***/
   /* prepare query string */
   snprintf(queryStr, BUFFMAXLN, 
 	   "insert into macmodify "
@@ -325,6 +326,18 @@ int putMacModifyLogToMngDb(char* userId, char* extraId, char* macAddr, char modi
 	   "values ('%s', '%s', '%s', '%c', now())",
 	   userId, extraId, macAddr, modifyType);
 
+  /* send SQL query */
+  if (mysql_query(&mysql, queryStr)){
+     err_msg("ERR at %s#%d: mysql query: %s",__FILE__,__LINE__,
+	     mysql_error(&mysql));
+     return FALSE;
+  }
+  /*** remove old log ***/ 
+  /* prepare query string */
+  snprintf(queryStr, BUFFMAXLN, 
+	   "delete from macmodify "
+	   " where modifyDate < adddate(now(), interval -1 day) ");
+
   /* send SQL query */
   if (mysql_query(&mysql, queryStr)){
      err_msg("ERR at %s#%d: mysql query: %s",__FILE__,__LINE__,
@@ -392,35 +405,18 @@ int countMacModifyPerDayInMngDb(char* userId, char* extraId, char* macAddress){
 
 /*********************************************************/
 /* delete a mac address registered in the management db  */
-/* in actuality, not delete row, but set the status="D"  */
-/*  when usage log for the address is found in log table */
+/* actuality, not delete row, but set the status="D"     */
 /* macAddr:(input)                                       */
 /*********************************************************/
 int delMacAddrFromMngDb(char* macAddr){
 
   char queryStr[BUFFMAXLN];
 
-  /* if the mac is found in the past session log,        */
-  /* the owner info is needed for the log inspection     */
-  /* thus the info is not deleted, but set as status="D" */
-  if(IsSessionFoundInMngDb(macAddr)){
-
     /* prepare query string */
     /* don't touch device of status="I"(set Inactive by admin) */
     snprintf(queryStr, BUFFMAXLN, 
 	     "update macaddrs set status='D',limitDate=now() "
 	     " where macAddress='%s' and (status='A' or status='P')", macAddr);
-  }
-
-  /* if mac is not found in past session log, the row is removed */
-  else{
-
-    /* prepare query string */
-    /* don't touch device of status="I"(set Inactive by admin) */
-    snprintf(queryStr, BUFFMAXLN, 
-	     "delete from macaddrs "
-	     " where macAddress='%s' and (status='A' or status='P')", macAddr);
-  }
 
   /* send SQL query */
   if (mysql_query(&mysql, queryStr)){
@@ -483,107 +479,6 @@ int pauseMacAddrInMngDb(char* macAddr){
   return TRUE;
 }
 
-/******************************************
- is the mac address used in session log
-******************************************/
-int isSessionFoundInMngDb(char* macAddr){
-
-  MYSQL_RES *res=NULL;
-  MYSQL_ROW row;
-  char queryStr[BUFFMAXLN];
-  int ret;
-
-  /* prepare query string */
-  /* get row for addr.entry<session.open<addr.limit */
-  snprintf(queryStr, BUFFMAXLN, 
-	   "select * from macaddrs, sessionmd "
-	   " where macaddrs.macAddress=sessionmd.macAddress and "
-	   " macaddrs.macAddress='%s' and "
-	   " entryDate<openTime and openTime<limitDate",
-	   macAddr);
-  
-  /* send SQL query */
-  if (mysql_query(&mysql, queryStr)){
-    err_msg("ERR at %s#%d: mysql query: %s",__FILE__,__LINE__,
-	    mysql_error(&mysql));
-    return FALSE;
-  }
-  
-  /* store result */
-  res = mysql_store_result(&mysql);
-
-  /* output table name */
-  row = mysql_fetch_row(res);
-  
-  /* if found, return true */
-  if(row!=NULL) ret=TRUE;
-
-  /* if not found, return false */
-  else ret=FALSE;
-
-  mysql_free_result(res);
-  return ret;
-}
-
-/*******************************************
- get next next usage log from management db
- if end of list, return false
-*******************************************/
-int getNextUsageLogFromMngDb(char* userId, char* extraId, char* macAddr, char* deviceName, char* openTime, char* closeTime, char* gatewayName){
-  static MYSQL_RES *res=NULL;
-  MYSQL_ROW row;
-  char queryStr[BUFFMAXLN];
-
-  /* set default values */
-  macAddr[0]=deviceName[0]=openTime[0]=gatewayName[0]='\0';
-
-  /* if do not get result yet */
-  if(res==NULL){
-
-    /* prepare query string */
-    /* get log where addr.entry < session.open < addr.limit */
-    /*  (the same device may be registered by other users in old days) */
-    snprintf(queryStr, BUFFMAXLN, 
-	     "select macaddrs.macAddress, device, openTime, closeTime, "
-	     " gatewayName "
-	     " from macaddrs, sessionmd "
-	     " where macaddrs.macAddress=sessionmd.macAddress "
-	     " and entryDate < openTime and openTime < limitDate "
-	     " and (%s<closeTime or closeTime=0) "
-	     " and userId='%s' and extraId='%s'",
-	     GetConfValue("ShowLogAfter"), userId, extraId);
-
-    /* send SQL query */
-    if (mysql_query(&mysql, queryStr)){
-      err_msg("ERR at %s#%d: mysql query: %s",__FILE__,__LINE__,
-	      mysql_error(&mysql));
-      return FALSE;
-    }
-    
-    /* store result */
-    res = mysql_store_result(&mysql);
-  }
-
-  /* output table name */
-  row = mysql_fetch_row(res);
-
-  /* if found, return values */
-  if(row!=NULL){
-    strlcpy(macAddr, row[0],ADDRMAXLN);
-    strlcpy(deviceName,row[1],WORDMAXLN);
-    strlcpy(openTime,row[2],WORDMAXLN);
-    strlcpy(closeTime,row[3],WORDMAXLN);
-    strlcpy(gatewayName,row[4],WORDMAXLN);
-    return TRUE;
-  }
-  /* if not found, free memory area */
-  else{
-    mysql_free_result(res);
-    return FALSE;
-  }
-}
-
-
 /*******************************************
  get next mail address near limit date
 from management db 
@@ -815,6 +710,51 @@ int isMacAddrStatusInactiveInMngDb(char* macAddr){
   return ret;
 }
 
+/******************************************************/
+/* Does the mac address belong to the userid@extraid  */
+/* all-args:(input)                                   */
+/* return value: true(1)=YES, false(0)=NO             */
+/******************************************************/
+int doesMacAddrBelongToUser(char* macAddr, char* userId, char* extraId){
+
+  MYSQL_RES *res=NULL;
+  MYSQL_ROW row;
+  char queryStr[BUFFMAXLN];
+  char existsStr[WORDMAXLN];
+  int exists=FALSE;
+
+  /* prepare query string */
+  snprintf(queryStr, BUFFMAXLN, 
+	   "select exists(select * from macaddrs "
+	   " where macAddress='%s' and userId='%s' "
+	   " and extraId='%s' and status!='D') ",
+	   macAddr, userId, extraId);
+
+  /* send SQL query */
+  if (mysql_query(&mysql, queryStr)){
+    err_msg("ERR at %s#%d: mysql query: %s",__FILE__,__LINE__,
+	    mysql_error(&mysql));
+    return FALSE;
+  }
+
+  /* store query result */
+  res = mysql_store_result(&mysql);
+
+  /* get a row from query result */
+  row = mysql_fetch_row(res);
+
+  /* if found, return the count */
+  if(row!=NULL){
+    strlcpy(existsStr, row[0], WORDMAXLN);
+    exists=atoi(existsStr);
+  }
+
+  /* free memory area */
+  mysql_free_result(res);
+
+  return exists;
+}
+
 /********************************************
  routines for debugging output
 ********************************************/
@@ -920,25 +860,6 @@ int PauseMacAddrInMngDb(char* macAddr){
   return ret;
 }
 
-int IsSessionFoundInMngDb(char* macAddr){
-  int ret;
-  if(debug>1) err_msg("DEBUG:=>isSessionFoundInMngDb(%s)",macAddr);
-  ret=isSessionFoundInMngDb(macAddr);
-  if(debug>1) err_msg("DEBUG:(%d)<=isSessionFoundInMngDb( )",ret);
-  return ret;
-}
-
-int GetNextUsageLogFromMngDb(char* userId, char* extraId, char* macAddr, 
- char* deviceName, char* openTime, char* closeTime, char* gatewayName){
-  int ret;
-  if(debug>1) err_msg("DEBUG:=>getNextUsageLogFromMngDb(%s,%s)",userId,extraId);
-  ret=getNextUsageLogFromMngDb(userId,extraId,macAddr,deviceName,
-			      openTime,closeTime,gatewayName);
-  if(debug>1) err_msg("DEBUG:(%d)<=getNextUsageLogFromMngDb(,,%s,%s,%s,%s,%s)",
-	         ret,macAddr,deviceName,openTime,closeTime,gatewayName);
-  return ret;
-}
-
 int GetNextMailAddressFromMngDb(char* mailAddress, char* limitDate, char*device){
   int ret;
   if(debug>1) err_msg("DEBUG:=>getnextMailAddressFromMngDb( )");
@@ -989,3 +910,12 @@ int IsMacAddrStatusInactiveInMngDb(char* macAddress){
   if(debug>1) err_msg("DEBUG:(%d)<=isMacAddrStatusInactiveInMngDb()",ret);
   return ret;
 }
+
+int DoesMacAddrBelongToUser(char* macAddr, char* userId, char* extraId){
+  int ret;
+  if(debug>1) err_msg("DEBUG:=>doesMacAddrBelongToUser(%s,%s,%s)",
+		      macAddr,userId,extraId);
+  ret=doesMacAddrBelongToUser(macAddr,userId,extraId);
+  if(debug>1) err_msg("DEBUG:(%d)<=doesMacAddrBelongToUser( )",ret);
+  return ret;
+}
