@@ -1,6 +1,11 @@
 /**************************************************
 OpengateM - MAC address authentication system 
- module for mac address checking child process control
+ module for child process control 
+
+ this module opens the network for the candidate of the user device.
+ (this is used in opengatemchk).
+ a child process opens net, sleeps while, and closes net automatically.
+ independent process is employed to perform a series of processing surely.
 
 Copyright (C) 2011 Opengate Project Team
 Written by Yoshiaki Watanabe
@@ -28,9 +33,9 @@ int rule4=0;
 int rule6=0;
 char loadPath[BUFFMAXLN];
 
-/**********************************************
-start child process to  open-net, sleep and close-net
-**********************************************/
+/**********************************************************/
+/* start child process that open-net, sleep and close-net */
+/**********************************************************/
 int startChildProc(char* macAddress){
 
   int dummyfd[2];
@@ -56,7 +61,7 @@ int startChildProc(char* macAddress){
     Close(0);Close(1);Close(2);
     Pipe(dummyfd);      /* connect dummy pipe for stdin and out */
 
-    /* get ipv4/ipv6 from db */
+    /* get ipv4/ipv6 corresponding to the mac from db */
     GetIpFromMacCheckTable(macAddress, ipv4, ipv6);
 
     /* open firewall */
@@ -66,7 +71,8 @@ int startChildProc(char* macAddress){
     /* save pid/ruleNumber to db */
     SavePidToMacCheckTable(macAddress, getpid(), rule4, rule6);
 
-    signal(SIGTERM, closeExit);
+    /* at TERM signal is received, call closeExit */
+    signalx(SIGTERM, closeExit);
 
     /* sleep a while */
     sleep(atoi(GetConfValue("OpenTimeout")));
@@ -79,9 +85,9 @@ int startChildProc(char* macAddress){
   }
 }
 
-/***************************
- signal function
-***************************/
+/***************************/
+/* signal function         */
+/***************************/
 void closeExit(int signo){
 
     /* close firewall */
@@ -90,9 +96,9 @@ void closeExit(int signo){
     exit(0);
 }
 
-/*********************************
- stop child process 
- ********************************/
+/*********************************/
+/* stop child process            */
+/*********************************/
 int stopChildProc(char* macAddress){
   
   int pid;
@@ -110,16 +116,16 @@ int stopChildProc(char* macAddress){
   return TRUE;
 }
 
-/**************************
-save the program load path
-**************************/
+/******************************/
+/* save the program load path */
+/******************************/
 void saveLoadPath(char* argv0){
   strlcpy(loadPath, argv0, BUFFMAXLN);
 }
 
-/******************************************
-get the program name extracted from argv[0]
-******************************************/
+/***********************************************/
+/* get the program name extracted from argv[0] */
+/***********************************************/
 char* getProgramName(void){
   char* pCh;
   pCh = strrchr(loadPath, '/');
@@ -128,7 +134,6 @@ char* getProgramName(void){
 }
 
 /*********************************************
- routines for debugging output
 **********************************************/
 int StartChildProc(char* macAddress){
   int ret;
